Pysaver

A utility to save the python REPL history to an external file.


Installation

python3 -m pip install pysaver


Usage

import pysaver

Saves entire REPL history to the file saved_repl_history.py in the current directory.
